@@ -65,7 +65,7 @@ bool esNoAttrs = FALSE;
 bool esHierAP = FALSE;
 char spcesDefaultOut[FNSIZE];
 int  esCapAccuracy = 1;
-char esCapFormat[FNSIZE];
+char esSpiceCapFormat[FNSIZE];
 char *spcesOutName = spcesDefaultOut;
 FILE *esSpiceF = NULL;
 float esScale = -1.0 ; /* negative if hspice the EFScale/100 otherwise */
@@ -98,7 +98,7 @@ struct {
    short resClassSD ;  /* the resistance class of the src/drn of the dev */
    short resClassSub ; /* the resistance class of the substrate of the dev */
    char  *defSubs ;    /* the default substrate node */
-} fetInfo[MAXDEVTYPES];
+} esFetInfo[MAXDEVTYPES];
 
 
 /* Node clients for figuring out areas and perimeters of sources and drains */
@@ -693,9 +693,9 @@ runexttospice:
        the command line arguments */
 
     for ( i = 0 ; i < MAXDEVTYPES ; i++ ) {
-	fetInfo[i].resClassSD = NO_RESCLASS;
-	fetInfo[i].resClassSub = NO_RESCLASS;
-	fetInfo[i].defSubs = NULL;
+	esFetInfo[i].resClassSD = NO_RESCLASS;
+	esFetInfo[i].resClassSub = NO_RESCLASS;
+	esFetInfo[i].defSubs = NULL;
     }
 
     /* Get fetInfo information from the current extraction style 	 */
@@ -715,9 +715,9 @@ runexttospice:
 	    esNoModelType = i;
 	if (EFStyle != NULL)
 	{
-	    fetInfo[i].resClassSD = sd_rclass;
-	    fetInfo[i].resClassSub = sub_rclass;
-	    fetInfo[i].defSubs = subname;
+	    esFetInfo[i].resClassSD = sd_rclass;
+	    esFetInfo[i].resClassSub = sub_rclass;
+	    esFetInfo[i].defSubs = subname;
 	}
 
 	/* Tcl variable substitution for substrate node names */
@@ -725,7 +725,7 @@ runexttospice:
 	{
 	    resstr = (char *)Tcl_GetVar(magicinterp, &subname[1],
 			TCL_GLOBAL_ONLY);
-	    if (resstr != NULL) fetInfo[i].defSubs = resstr;
+	    if (resstr != NULL) esFetInfo[i].defSubs = resstr;
 	}
     }
 
@@ -794,12 +794,12 @@ runexttospice:
     initMask = (unsigned long) 0;
     if (flatFlags & EF_FLATCAPS)
     {
-	(void) sprintf( esCapFormat,  "C%%d %%s %%s %%.%dlffF\n", esCapAccuracy);
+	(void) sprintf( esSpiceCapFormat,  "C%%d %%s %%s %%.%dlffF\n", esCapAccuracy);
 	EFVisitCaps(spccapVisit, (ClientData) NULL);
     }
     EFVisitResists(spcresistVisit, (ClientData) NULL);
     EFVisitSubcircuits(subcktVisit, (ClientData) NULL);
-    (void) sprintf( esCapFormat, "C%%d %%s %s %%.%dlffF%%s", resstr, esCapAccuracy);
+    (void) sprintf( esSpiceCapFormat, "C%%d %%s %s %%.%dlffF%%s", resstr, esCapAccuracy);
     EFVisitNodes(spcnodeVisit, (ClientData) NULL);
 
     if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
@@ -847,26 +847,26 @@ main(argc, argv)
     /* create default devinfo entries (MOSIS) which can be overriden by
        the command line arguments */
     for ( i = 0 ; i < MAXDEVTYPES ; i++ ) {
-	fetInfo[i].resClassSD = NO_RESCLASS;
-	fetInfo[i].resClassSub = NO_RESCLASS;
-	fetInfo[i].defSubs = NULL;
+	esFetInfo[i].resClassSD = NO_RESCLASS;
+	esFetInfo[i].resClassSub = NO_RESCLASS;
+	esFetInfo[i].defSubs = NULL;
     }
     i = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, "ndev");
-    fetInfo[i].resClassSD = 0 ;
-    fetInfo[i].resClassSub = NO_RESCLASS ;
-    fetInfo[i].defSubs = "Gnd!";
+    esFetInfo[i].resClassSD = 0 ;
+    esFetInfo[i].resClassSub = NO_RESCLASS ;
+    esFetInfo[i].defSubs = "Gnd!";
     i = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, "pdev");
-    fetInfo[i].resClassSD = 1 ;
-    fetInfo[i].resClassSub = 8 ;
-    fetInfo[i].defSubs = "Vdd!";
+    esFetInfo[i].resClassSD = 1 ;
+    esFetInfo[i].resClassSub = 8 ;
+    esFetInfo[i].defSubs = "Vdd!";
     i = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, "nmos");
-    fetInfo[i].resClassSD = 0 ;
-    fetInfo[i].resClassSub = NO_RESCLASS ;
-    fetInfo[i].defSubs = "Gnd!";
+    esFetInfo[i].resClassSD = 0 ;
+    esFetInfo[i].resClassSub = NO_RESCLASS ;
+    esFetInfo[i].defSubs = "Gnd!";
     i = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, "pmos");
-    fetInfo[i].resClassSD = 1 ;
-    fetInfo[i].resClassSub = 8 ;
-    fetInfo[i].defSubs = "Vdd!";
+    esFetInfo[i].resClassSD = 1 ;
+    esFetInfo[i].resClassSub = 8 ;
+    esFetInfo[i].defSubs = "Vdd!";
     /* Process command line arguments */
 
     inName = EFArgs(argc, argv, NULL, spcmainArgs, (ClientData) NULL);
@@ -947,12 +947,12 @@ main(argc, argv)
     EFVisitDevs(spcdevVisit, (ClientData) NULL);
     initMask = (unsigned long) 0;
     if (flatFlags & EF_FLATCAPS) {
-	(void) sprintf( esCapFormat,  "C%%d %%s %%s %%.%dlffF\n",esCapAccuracy);
+	(void) sprintf( esSpiceCapFormat,  "C%%d %%s %%s %%.%dlffF\n",esCapAccuracy);
 	EFVisitCaps(spccapVisit, (ClientData) NULL);
     }
     EFVisitResists(spcresistVisit, (ClientData) NULL);
     EFVisitSubcircuits(subcktVisit, (ClientData) NULL);
-    (void) sprintf( esCapFormat, "C%%d %%s GND %%.%dlffF%%s", esCapAccuracy);
+    (void) sprintf( esSpiceCapFormat, "C%%d %%s GND %%.%dlffF%%s", esCapAccuracy);
     EFVisitNodes(spcnodeVisit, (ClientData) NULL);
 
     if ((esDoSubckt == TRUE) || (locDoSubckt == TRUE))
@@ -1081,8 +1081,8 @@ spcmainArgs(pargc, pargv)
 	    	if ( sscanf(rp, "%d/%s",  &rClass, subsNode) != 2 ) goto usage;
 	    }
 	    ndx = efBuildAddStr(EFDevTypes, &EFDevNumTypes, MAXDEVTYPES, cp);
-	    fetInfo[ndx].resClassSD = rClass;
-	    fetInfo[ndx].resClassSub = rClassSub;
+	    esFetInfo[ndx].resClassSD = rClass;
+	    esFetInfo[ndx].resClassSub = rClassSub;
 	    if ( ((1<<rClass) & DEV_CONNECT_MASK) ||
 	         ((1<<rClass) & DEV_CONNECT_MASK)   ) {
 	        TxError("Oops it seems that you have 31\n");
@@ -1091,11 +1091,11 @@ spcmainArgs(pargc, pargv)
 	        TxError("DEV_CONNECT_MASK and or nodeClient\n");
 		exit (1);
 	    }
-	    fetInfo[ndx].defSubs = (char *) mallocMagic((unsigned) (strlen(subsNode)+1));
-	    strcpy(fetInfo[ndx].defSubs,subsNode);
+	    esFetInfo[ndx].defSubs = (char *)mallocMagic((unsigned)(strlen(subsNode)+1));
+	    strcpy(esFetInfo[ndx].defSubs,subsNode);
 	    TxError("info: dev %s(%d) sdRclass=%d subRclass=%d dSub=%s\n", 
-	    cp, ndx, fetInfo[ndx].resClassSD, fetInfo[ndx].resClassSub, 
-            fetInfo[ndx].defSubs);
+	    cp, ndx, esFetInfo[ndx].resClassSD, esFetInfo[ndx].resClassSub, 
+            esFetInfo[ndx].defSubs);
 	    break;
 	    }
 #endif			/* MAGIC_WRAPPER */
@@ -1982,33 +1982,33 @@ spcdevVisit(dev, hierName, trans)
 
 	    fprintf(esSpiceF, "\n+ ");
 	    if (hierD) 
-        	spcnAPHier(drain, hierName, fetInfo[dev->dev_type].resClassSD,
+        	spcnAPHier(drain, hierName, esFetInfo[dev->dev_type].resClassSD,
 			scale, "d", sdM, esSpiceF);
 	    else
 	    {
 		dnode = SpiceGetNode(hierName, drain->dterm_node->efnode_name->efnn_hier);
-        	spcnAP(dnode, fetInfo[dev->dev_type].resClassSD, scale,
+        	spcnAP(dnode, esFetInfo[dev->dev_type].resClassSD, scale,
 			"d", sdM, esSpiceF, w);
 	    }
 	    if (hierS)
-		spcnAPHier(source, hierName, fetInfo[dev->dev_type].resClassSD,
+		spcnAPHier(source, hierName, esFetInfo[dev->dev_type].resClassSD,
 			scale, "s", sdM, esSpiceF);
 	    else {
 		snode= SpiceGetNode(hierName, source->dterm_node->efnode_name->efnn_hier);
-		spcnAP(snode, fetInfo[dev->dev_type].resClassSD, scale,
+		spcnAP(snode, esFetInfo[dev->dev_type].resClassSD, scale,
 			"s", sdM, esSpiceF, w);
 	    }
 	    if (subAP)
 	    {
 		fprintf(esSpiceF, " * ");
-		if (fetInfo[dev->dev_type].resClassSub < 0)
+		if (esFetInfo[dev->dev_type].resClassSub < 0)
 		{
 		    TxError("error: subap for devtype %d unspecified\n",
 				dev->dev_type);
 		    fprintf(esSpiceF, "asub=0 psub=0");
 		}
 		else if (subnodeFlat) 
-		    spcnAP(subnodeFlat, fetInfo[dev->dev_type].resClassSub, scale, 
+		    spcnAP(subnodeFlat, esFetInfo[dev->dev_type].resClassSub, scale, 
 	       			"sub", sdM, esSpiceF, -1);
 		else
 		    fprintf(esSpiceF, "asub=0 psub=0");
@@ -2062,7 +2062,7 @@ FILE *outf;
     int  l ;
 
     suf = EFHNToStr(suffix);
-    if (fetInfo[type].defSubs && strcasecmp(suf,fetInfo[type].defSubs) == 0) {
+    if (esFetInfo[type].defSubs && strcasecmp(suf,esFetInfo[type].defSubs) == 0) {
 	if ( outf ) {
     	   l = strlen(suf) - 1;
 	   if (  ( EFTrimFlags & EF_TRIMGLOB ) && suf[l] =='!' ||
@@ -2119,7 +2119,7 @@ int spcnAP(node, resClass, scale, sterm, m, outf, w)
 	if ((node == NULL) || (node->efnode_client == (ClientData)NULL))
 	{
 	    TxError("spcnAP: major internal inconsistency\n");
-	    return;
+	    return 1;
 	}
 
 	if ( esScale < 0 )
@@ -2138,7 +2138,7 @@ int spcnAP(node, resClass, scale, sterm, m, outf, w)
 	    ((float)node->efnode_pa[resClass].pa_area*scale*scale)
 	    *esScale*esScale*dsc,
 	    ((float)node->efnode_pa[resClass].pa_perim*scale)*esScale*dsc);
-	return;
+	return 0;
 
 oldFmt:
 	if ( resClass == NO_RESCLASS ||
@@ -2153,6 +2153,7 @@ oldFmt:
 	   fprintf(outf,fmt,
 	    ((float)node->efnode_pa[resClass].pa_area*scale*scale)*esScale*esScale,
 	    ((float)node->efnode_pa[resClass].pa_perim*scale)*esScale);
+	return 0;
 }
 
 int spcnAPHier(dterm, hierName, resClass, scale, sterm, m, outf)
@@ -2190,6 +2191,7 @@ int spcnAPHier(dterm, hierName, resClass, scale, sterm, m, outf)
 	   fprintf(outf,fmt,
 	    ((float)node->efnode_pa[resClass].pa_area*scale)*esScale*esScale,
 	    ((float)node->efnode_pa[resClass].pa_perim*scale)*esScale);
+	return 0;
 }
 
 /*
@@ -2226,10 +2228,11 @@ spcdevOutNode(prefix, suffix, name, outf)
     if (he == NULL)
     {
 	fprintf(outf, " errGnd!");
-	return;
+	return 0;
     }
     nn = (EFNodeName *) HashGetValue(he);
     fprintf(outf, " %s", nodeSpiceName(nn->efnn_node->efnode_name->efnn_hier));
+    return 0;
 }
 
 
@@ -2268,7 +2271,7 @@ spccapVisit(hierName1, hierName2, cap)
     if (cap <= EFCapThreshold)
 	return 0;
 
-    fprintf(esSpiceF, esCapFormat ,esCapNum++,nodeSpiceName(hierName1),
+    fprintf(esSpiceF, esSpiceCapFormat ,esCapNum++,nodeSpiceName(hierName1),
                                           nodeSpiceName(hierName2), cap);
     return 0;
 }
@@ -2366,7 +2369,7 @@ spcnodeVisit(node, res, cap)
     cap = cap  / 1000;
     if (cap > EFCapThreshold)
     {
-	fprintf(esSpiceF, esCapFormat, esCapNum++, nsn, cap,
+	fprintf(esSpiceF, esSpiceCapFormat, esCapNum++, nsn, cap,
 			  (isConnected) ?  "\n" : " **FLOATING\n");
     }
     if (node->efnode_attrs && !esNoAttrs)
@@ -2508,6 +2511,7 @@ EFHNSprintf(str, hierName)
 	*str++ = '\0';
     }
     else strcpy(str, hierName->hn_name);
+    return 0;
 }
 
 char *efHNSprintfPrefix(hierName, str)
@@ -2604,6 +2608,7 @@ topLevel:
 #endif
 	}
     }
+    return 0;
 }
 
 /*
@@ -2638,6 +2643,7 @@ int printSubcktDict()
     while ((he = HashNext(&subcktNameTable, &hs)) != NULL) 
 #endif
 	fprintf(esSpiceF,"* x%d\t%s\n", HashGetValue(he), he->h_key.h_name);
+    return 0;
 }
 
 /*
@@ -3002,6 +3008,7 @@ update_w(resClass, w,  n)
 	    nc->m_w.widths[i] = 0.0;
     }
     nc->m_w.widths[resClass] += (float)w;
+    return 0;
 }
 
 /*
@@ -3045,7 +3052,7 @@ devDistJunctVisit(dev, hierName, trans)
     {
 	n = SpiceGetNode(hierName,
 		dev->dev_terms[i].dterm_node->efnode_name->efnn_hier);
-	update_w(fetInfo[dev->dev_type].resClassSD, w, n);
+	update_w(esFetInfo[dev->dev_type].resClassSD, w, n);
     }
     return 0;
 }
