@@ -67,6 +67,8 @@ extern bool GrTOGLInit();
 extern bool GrTOGLEventPending(), GrTOGLCreate(), grtoglGetCursorPos();
 extern int  GrTOGLWindowId();
 extern char *GrTkWindowName();
+
+extern void toglSetProjection();
 
 /*---------------------------------------------------------
  * grtoglSetWMandC:
@@ -378,7 +380,7 @@ static GLXPixmap glpmap;
  *---------------------------------------------------------
  */
 
-int
+void
 toglSetProjection(llx, lly, width, height)
     int llx, lly, width, height;
 {
@@ -517,7 +519,7 @@ keys_and_buttons:
 		keymod = (LockMask | ControlMask | ShiftMask)
 				& KeyPressedEvent->state;
 
-#ifdef macosx
+#ifdef __APPLE__
 		/* Change by Philippe---Allows magic to deal with Mac OS-X
 		 * mapping Meta to Mod2 instead of Mod1
 		 */
